#!/usr/bin/python

from macaroon.playback import *
import utils

sequence = MacroSequence()

#sequence.append(WaitForDocLoad())
sequence.append(PauseAction(5000))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Control>Home"))
sequence.append(utils.AssertPresentationAction(
    "1. Top of file",
    ["BRAILLE LINE:  'MathML mfenced test cases'",
     "     VISIBLE:  'MathML mfenced test cases', cursor=1",
     "SPEECH OUTPUT: 'MathML mfenced test cases'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Down"))
sequence.append(utils.AssertPresentationAction(
    "2. Line Down",
    ["BRAILLE LINE:  'math'",
     "     VISIBLE:  'math', cursor=0",
     "SPEECH OUTPUT: 'left paren.'",
     "SPEECH OUTPUT: 'a comma.'",
     "SPEECH OUTPUT: 'b comma.'",
     "SPEECH OUTPUT: 'c comma.'",
     "SPEECH OUTPUT: 'd comma.'",
     "SPEECH OUTPUT: 'e.'",
     "SPEECH OUTPUT: 'right paren'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Down"))
sequence.append(utils.AssertPresentationAction(
    "3. Line Down",
    ["BRAILLE LINE:  'math'",
     "     VISIBLE:  'math', cursor=0",
     "SPEECH OUTPUT: 'left brace.'",
     "SPEECH OUTPUT: 'a semicolon.'",
     "SPEECH OUTPUT: 'b semicolon.'",
     "SPEECH OUTPUT: 'c semicolon.'",
     "SPEECH OUTPUT: 'd semicolon.'",
     "SPEECH OUTPUT: 'e.'",
     "SPEECH OUTPUT: 'right brace'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Down"))
sequence.append(utils.AssertPresentationAction(
    "4. Line Down",
    ["BRAILLE LINE:  'math'",
     "     VISIBLE:  'math', cursor=0",
     "SPEECH OUTPUT: 'left brace.'",
     "SPEECH OUTPUT: 'a semicolon.'",
     "SPEECH OUTPUT: 'b semicolon.'",
     "SPEECH OUTPUT: 'c comma.'",
     "SPEECH OUTPUT: 'd comma.'",
     "SPEECH OUTPUT: 'e.'",
     "SPEECH OUTPUT: 'right brace'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Down"))
sequence.append(utils.AssertPresentationAction(
    "5. Line Down",
    ["BRAILLE LINE:  'End of test'",
     "     VISIBLE:  'End of test', cursor=1",
     "SPEECH OUTPUT: 'End of test'"]))

sequence.append(utils.AssertionSummaryAction())
sequence.start()



#!/usr/bin/python

"""Test of presentation of lines that contain images."""

from macaroon.playback import *
import utils

sequence = MacroSequence()

#sequence.append(WaitForDocLoad())
sequence.append(PauseAction(5000))

# Work around some quirk in Gecko that causes this test to fail if
# run via the test harness rather than manually.
sequence.append(KeyComboAction("<Control>r"))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Control>Home"))
sequence.append(utils.AssertPresentationAction(
    "1. Top of file",
    ["BRAILLE LINE:  'Start'",
     "     VISIBLE:  'Start', cursor=1",
     "SPEECH OUTPUT: 'Start'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Down"))
sequence.append(utils.AssertPresentationAction(
    "2. Line Down",
    ["BRAILLE LINE:  'classic image Options image'",
     "     VISIBLE:  'classic image Options image', cursor=1",
     "SPEECH OUTPUT: 'classic image'",
     "SPEECH OUTPUT: 'Options image'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Down"))
sequence.append(utils.AssertPresentationAction(
    "3. Line Down",
    ["BRAILLE LINE:  'End'",
     "     VISIBLE:  'End', cursor=1",
     "SPEECH OUTPUT: 'End'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Up"))
sequence.append(utils.AssertPresentationAction(
    "4. Line Up",
    ["BRAILLE LINE:  'classic image Options image'",
     "     VISIBLE:  'classic image Options image', cursor=1",
     "SPEECH OUTPUT: 'classic image'",
     "SPEECH OUTPUT: 'Options image'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Up"))
sequence.append(utils.AssertPresentationAction(
    "5. Line Up",
    ["BRAILLE LINE:  'Start'",
     "     VISIBLE:  'Start', cursor=1",
     "SPEECH OUTPUT: 'Start'"]))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
